@@ -158,6 +158,7 @@ class Component:
         parent = dom.GetParent()
         # TODO: is any of this right..?
         if hasattr(dom, '_instance') and type(dom._instance).__name__ == vdom['type'].__name__:
+            dom._instance.props = vdom['props']
             return patch(dom, dom._instance.render())
         if cls.__name__ == vdom['type'].__name__:
             return cls.render_component(vdom, parent)
@@ -165,13 +166,10 @@ class Component:
             return patch(dom, vdom['type'](vdom['props']))
 
 
-
-
     def component_did_mount(self):
         pass
 
     def component_will_unmount(self):
-        print('gooodbye!')
         pass
 
     def render(self):
